#[repr(transparent)]pub struct Usb2ChrgDetectStat(pub u32);Expand description
USB Charger Detect Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb2ChrgDetectStat
impl Usb2ChrgDetectStat
Sourcepub const fn plug_contact(&self) -> Usb2ChrgDetectStatPlugContact
pub const fn plug_contact(&self) -> Usb2ChrgDetectStatPlugContact
State of the USB plug contact detector.
Sourcepub const fn set_plug_contact(&mut self, val: Usb2ChrgDetectStatPlugContact)
pub const fn set_plug_contact(&mut self, val: Usb2ChrgDetectStatPlugContact)
State of the USB plug contact detector.
Sourcepub const fn chrg_detected(&self) -> Usb2ChrgDetectStatChrgDetected
pub const fn chrg_detected(&self) -> Usb2ChrgDetectStatChrgDetected
State of charger detection. This bit is a read only version of the state of the analog signal.
Sourcepub const fn set_chrg_detected(&mut self, val: Usb2ChrgDetectStatChrgDetected)
pub const fn set_chrg_detected(&mut self, val: Usb2ChrgDetectStatChrgDetected)
State of charger detection. This bit is a read only version of the state of the analog signal.
Sourcepub const fn set_dm_state(&mut self, val: bool)
pub const fn set_dm_state(&mut self, val: bool)
DM line state output of the charger detector.
Sourcepub const fn set_dp_state(&mut self, val: bool)
pub const fn set_dp_state(&mut self, val: bool)
DP line state output of the charger detector.